Collection class

Represents a BGG collection containing multiple items.

Constructors

Collection({required List<CollectionItem> items})
Collection.fromXml(XmlElement root)
Parses a Collection from an XML root element.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<CollectionItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited