SearchResultItem class

A single search result item.

Constructors

SearchResultItem({required int id, required String name, String? type, int? yearPublished, String? thumbnailUrl, String? imageUrl})
SearchResultItem.fromXml(XmlElement xml)
Parse one <item> element from the /search response.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
BGG’s integer ID for this item.
final
imageUrl String?
URL to the full-size image.
final
name String
The name value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl String?
URL to the thumbnail (small) image.
final
type String?
Thing-type (e.g. “boardgame”).
final
yearPublished int?
Year published, if present.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited