SearchResults class

Wraps a list of SearchResultItems.

Constructors

SearchResults({required List<SearchResultItem> items})
SearchResults.fromXml(XmlElement root)
Parse root <items> element into SearchResults.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<SearchResultItem>
All matched items.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited